﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.WebEdition;

namespace Wmts_Sample
{
    [Serializable]
    public class WmtsOverlay : Overlay
    {
        private bool isBaseLayer;
        private string version;
        private WmtsRquestEncoding requestEncoding;
        private Uri serverUri;
        private string style;
        private PointShape tileOrigin;
        private RectangleShape tileFullExtent;
        private string formatSuffix;
        private Collection<string> dimensions;
        private Dictionary<string, string> parameters;
        private string matrix;
        private int zoomOffset;
        private WebImageFormat format;
        private Collection<string> matrixIds;
        private string layer;
        private string matrixSet;

        public WmtsOverlay(Uri uri)
        {
            this.RequestEncoding = WmtsRquestEncoding.KVP;
            this.Version = "1.0.0";
            this.MatrixSet = "EPSG:900913";
            this.Format = WebImageFormat.Jpeg;
            this.serverUri = uri;
        }

        [JsonMember(MemberName = "serverUri")]
        public Uri ServerUri
        {
            get { return serverUri; }
        }

        [JsonMember(MemberName = "layer")]
        public string Layer
        {
            get { return layer; }
            set
            {
                layer = value;
            }
        }

        [JsonMember(MemberName = "matrixSet")]
        public string MatrixSet
        {
            get
            {
                return matrixSet;
            }
            set
            {
                matrixSet = value;
            }
        }

        [JsonMember(MemberName = "matrixIds")]
        public Collection<string> MatrixIds
        {
            get
            {
                if (matrixIds == null)
                {
                    matrixIds = new Collection<string>();
                }
                return matrixIds;
            }
        }

        [JsonMember(MemberName = "format")]
        public WebImageFormat Format
        {
            get
            {
                return format;
            }
            set
            {
                format = value;
            }
        }

        [JsonMember(MemberName = "version")]
        public string Version
        {
            get
            {
                return version;
            }
            set
            {
                version = value;
            }
        }

        [JsonMember(MemberName = "encoding")]
        public WmtsRquestEncoding RequestEncoding
        {
            get
            {
                return requestEncoding;
            }
            set
            {
                requestEncoding = value;
            }
        }

        [JsonMember(MemberName = "style")]
        public string Style
        {
            get { return style; }
            set { style = value; }
        }

        [JsonMember(MemberName = "formatSuffix")]
        public string FormatSuffix
        {
            get { return formatSuffix; }
            set { formatSuffix = value; }
        }

        [JsonMember(MemberName = "dimensions")]
        public Collection<string> Dimensions
        {
            get
            {
                if (dimensions == null)
                {
                    dimensions = new Collection<string>();
                }
                return dimensions;
            }
        }

        [JsonMember(MemberName = "params")]
        public Dictionary<string, string> Parameters
        {
            get
            {
                if (parameters == null)
                {
                    parameters = new Dictionary<string, string>();
                }
                return parameters;
            }
        }

        /// <summary>Gets a string that indicates the overlay type.</summary>
        /// <value>A string that indicates the overlay type.</value>
        [JsonMember(MemberName = "otype")]
        protected override string OverlayType
        {
            get
            {
                return "WMTS";
            }
        }
    }
}